![](https://sharadcodes.github.io/logos/sharnote/sharlogo.png)

A command line note taking utility developed in Python that saves notes in JSON format.
                    
# Installation

```
pip3 install sharnote
```

# Usage

### For help

```
sharnote --help or sharnote --h
```

### To see notes of today

```
sharnote --today or --t
```

### To see notes of a particaular date

```
sharnote --date or --d YYYY-MM-DD
```

### To search for a particular string in notes

```
sharnote --search or --s "Some text here"
```

### To change directory used for storing notes

```
sharnote --notesdir or --nd
```
